==> percona-server-mongodb_4.0.28.orig.tar.gz: percona-server-mongodb-4.0.28-23/aws-sdk-cpp/aws-cpp-sdk-polly/source/model/DescribeVoicesRequest.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/polly/model/DescribeVoicesRequest.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/http/URI.h>
#include <aws/core/utils/memory/stl/AWSStringStream.h>

#include <utility>

using namespace Aws::Polly::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws::Http;

DescribeVoicesRequest::DescribeVoicesRequest() : 
    m_engine(Engine::NOT_SET),
    m_engineHasBeenSet(false),
    m_languageCode(LanguageCode::NOT_SET),
    m_languageCodeHasBeenSet(false),
    m_includeAdditionalLanguageCodes(false),
    m_includeAdditionalLanguageCodesHasBeenSet(false),
    m_nextTokenHasBeenSet(false)
{
}

Aws::String DescribeVoicesRequest::SerializePayload() const
{
  return {};
}

void DescribeVoicesRequest::AddQueryStringParameters(URI& uri) const
{
    Aws::StringStream ss;
    if(m_engineHasBeenSet)
    {
      ss << EngineMapper::GetNameForEngine(m_engine);
      uri.AddQueryStringParameter("Engine", ss.str());
      ss.str("");
    }

    if(m_languageCodeHasBeenSet)
    {
      ss << LanguageCodeMapper::GetNameForLanguageCode(m_languageCode);
      uri.AddQueryStringParameter("LanguageCode", ss.str());
      ss.str("");
    }

    if(m_includeAdditionalLanguageCodesHasBeenSet)
    {
      ss << m_includeAdditionalLanguageCodes;
      uri.AddQueryStringParameter("IncludeAdditionalLanguageCodes", ss.str());
      ss.str("");
    }

    if(m_nextTokenHasBeenSet)
    {
      ss << m_nextToken;
      uri.AddQueryStringParameter("NextToken", ss.str());
      ss.str("");
    }

}

==> percona-server-mongodb_4.4.1.orig.tar.gz: percona-server-mongodb-4.4.1-2/aws-sdk-cpp/aws-cpp-sdk-polly/source/model/DescribeVoicesRequest.cpp <==
﻿/*
* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
*
* Licensed under the Apache License, Version 2.0 (the "License").
* You may not use this file except in compliance with the License.
* A copy of the License is located at
*
*  http://aws.amazon.com/apache2.0
*
* or in the "license" file accompanying this file. This file is distributed
* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
* express or implied. See the License for the specific language governing
* permissions and limitations under the License.
*/

#include <aws/polly/model/DescribeVoicesRequest.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/http/URI.h>
#include <aws/core/utils/memory/stl/AWSStringStream.h>

#include <utility>

using namespace Aws::Polly::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws::Http;

DescribeVoicesRequest::DescribeVoicesRequest() : 
    m_languageCode(LanguageCode::NOT_SET),
    m_languageCodeHasBeenSet(false),
    m_includeAdditionalLanguageCodes(false),
    m_includeAdditionalLanguageCodesHasBeenSet(false),
    m_nextTokenHasBeenSet(false)
{
}

Aws::String DescribeVoicesRequest::SerializePayload() const
{
  return {};
}

void DescribeVoicesRequest::AddQueryStringParameters(URI& uri) const
{
    Aws::StringStream ss;
    if(m_languageCodeHasBeenSet)
    {
      ss << LanguageCodeMapper::GetNameForLanguageCode(m_languageCode);
      uri.AddQueryStringParameter("LanguageCode", ss.str());
      ss.str("");
    }

    if(m_includeAdditionalLanguageCodesHasBeenSet)
    {
      ss << m_includeAdditionalLanguageCodes;
      uri.AddQueryStringParameter("IncludeAdditionalLanguageCodes", ss.str());
      ss.str("");
    }

    if(m_nextTokenHasBeenSet)
    {
      ss << m_nextToken;
      uri.AddQueryStringParameter("NextToken", ss.str());
      ss.str("");
    }

}
